@@ -16,13 +16,11 @@ from pyoperators.utils import float_or_complex_dtype, product
 from pyoperators.utils.testing import (
     assert_eq, assert_is, assert_is_instance, assert_is_none, assert_is_not,
     assert_is_type, assert_not_in, assert_same)
-from .common import HomothetyOutplaceOperator
+from .common import DTYPES, HomothetyOutplaceOperator
 
 clss = (ConstantOperator, DiagonalOperator, DiagonalNumexprOperator,
         HomothetyOperator, IdentityOperator, MaskOperator, ZeroOperator)
 sameshapes = ((False, True), (True, True), (True, True), (True, True))
-types = (bool, np.int8, np.int16, np.int32, np.int64, np.float16, np.float32,
-         np.float64, np.float128, np.complex128, np.complex256)
 
 
 def get_operator(cls, data, **keywords):
@@ -368,7 +366,7 @@ def test_dtype():
             assert_equal(op.dtype, t)
 
     for c in clss:
-        for t in types:
+        for t in [bool] + DTYPES:
             yield func, c, t
 
 
