@@ -7,7 +7,7 @@ from contextlib import contextmanager
 from numpy.testing import assert_equal, assert_warns
 from pyoperators import Operator
 from pyoperators.utils import (
-    broadcast_shapes, cast, complex_dtype, complex_intrinsic_dtype, deprecated,
+    broadcast_shapes, cast, complex_dtype, deprecated,
     first, first_is_not, float_dtype, float_intrinsic_dtype,
     float_or_complex_dtype, ifirst, ifirst_is_not, ilast, ilast_is_not,
     groupbykey, inspect_special_values, interruptible, isscalarlike,
@@ -18,10 +18,7 @@ from pyoperators.utils import (
 from pyoperators.utils.testing import (
     assert_eq, assert_not_in, assert_raises, assert_same)
 from pyoperators.warnings import PyOperatorsDeprecationWarning
-
-dtypes = [np.dtype(t) for t in (np.bool8, np.uint8, np.int8, np.uint16,
-          np.int16, np.uint32, np.int32, np.uint64, np.int64, np.float32,
-          np.float64, np.float128, np.complex64, np.complex128, np.complex256)]
+from .common import BIGGEST_FLOAT_TYPE, COMPLEX_DTYPES, FLOAT_DTYPES, DTYPES
 
 
 def assert_dtype(a, d):
@@ -110,16 +107,19 @@ def test_cast():
 
 
 def test_complex_dtype():
-    dtypes = (str, bool, int, np.uint32,
-              np.float16, np.float32, np.float64, np.float128,
-              np.complex64, np.complex128, np.complex256,
-              '>f2', '>f4', '>f8', '>f16',
-              '>c8', '>c16', '>c32')
-    expecteds = (None, '<c16', '<c16', '<c16',
-                 '<c16', '<c8', '<c16', '<c32',
-                 '<c8', '<c16', '<c32',
-                 '<c16', '>c8', '>c16', '>c32',
-                 '>c8', '>c16', '>c32')
+    dtypes = [str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64,
+              np.complex64, np.complex128,
+              '>f2', '>f4', '>f8',
+              '>c8', '>c16']
+    expecteds = [None, '<c16', '<c16', '<c16',
+                 '<c16', '<c8', '<c16',
+                 '<c8', '<c16',
+                 '<c16', '>c8', '>c16',
+                 '>c8', '>c16']
+    if hasattr(np, 'float128'):
+        dtypes.extend([np.float128, '>f16', np.complex256, '>c32'])
+        expecteds.extend(['<c32', '>c32', '<c32', '>c32'])
 
     def func(dtype, expected):
         if expected is None:
@@ -131,39 +131,20 @@ def test_complex_dtype():
         yield func, dtype, expected
 
 
-def test_complex_intrinsic_dtype():
-    dtypes = (str, bool, int, np.uint32,
-              np.float16, np.float32, np.float64, np.float128,
-              np.complex64, np.complex128, np.complex256,
-              '>f2', '>f4', '>f8', '>f16',
-              '>c8', '>c16', '>c32')
-    expecteds = (None, '<c16', '<c16', '<c16',
-                 '<c8', '<c8', '<c16', '<c16',
-                 '<c8', '<c16', '<c16',
-                 '<c8', '<c8', '<c16', '<c16',
-                 '<c8', '<c16', '<c16')
-
-    def func(dtype, expected):
-        if expected is None:
-            assert_raises(TypeError, complex_dtype, dtype)
-        else:
-            actual = complex_intrinsic_dtype(dtype)
-            assert_eq(actual.str, expected)
-    for dtype, expected in zip(dtypes, expecteds):
-        yield func, dtype, expected
-
-
 def test_float_dtype():
-    dtypes = (str, bool, int, np.uint32,
-              np.float16, np.float32, np.float64, np.float128,
-              np.complex64, np.complex128, np.complex256,
-              '>f2', '>f4', '>f8', '>f16',
-              '>c8', '>c16', '>c32')
-    expecteds = (None, '<f8', '<f8', '<f8',
-                 '<f2', '<f4', '<f8', '<f16',
-                 '<f4', '<f8', '<f16',
-                 '>f2', '>f4', '>f8', '>f16',
-                 '>f4', '>f8', '>f16')
+    dtypes = [str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64,
+              np.complex64, np.complex128,
+              '>f2', '>f4', '>f8',
+              '>c8', '>c16']
+    expecteds = [None, '<f8', '<f8', '<f8',
+                 '<f2', '<f4', '<f8',
+                 '<f4', '<f8',
+                 '>f2', '>f4', '>f8',
+                 '>f4', '>f8']
+    if hasattr(np, 'float128'):
+        dtypes.extend([np.float128, '>f16', np.complex256, '>c32'])
+        expecteds.extend(['<f16', '>f16', '<f16', '>f16'])
 
     def func(dtype, expected):
         if expected is None:
@@ -176,16 +157,19 @@ def test_float_dtype():
 
 
 def test_float_intrinsic_dtype():
-    dtypes = (str, bool, int, np.uint32,
-              np.float16, np.float32, np.float64, np.float128,
-              np.complex64, np.complex128, np.complex256,
-              '>f2', '>f4', '>f8', '>f16',
-              '>c8', '>c16', '>c32')
-    expecteds = (None, '<f8', '<f8', '<f8',
-                 '<f4', '<f4', '<f8', '<f8',
-                 '<f4', '<f8', '<f8',
-                 '<f4', '<f4', '<f8', '<f8',
-                 '<f4', '<f8', '<f8')
+    dtypes = [str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64,
+              np.complex64, np.complex128,
+              '>f2', '>f4', '>f8',
+              '>c8', '>c16']
+    expecteds = [None, '<f8', '<f8', '<f8',
+                 '<f4', '<f4', '<f8',
+                 '<f4', '<f8',
+                 '<f4', '<f4', '<f8',
+                 '<f4', '<f8']
+    if hasattr(np, 'float128'):
+        dtypes.extend([np.float128, '>f16', np.complex256, '>c32'])
+        expecteds.extend(['<f8', '<f8', '<f8', '<f8'])
 
     def func(dtype, expected):
         if expected is None:
@@ -198,16 +182,19 @@ def test_float_intrinsic_dtype():
 
 
 def test_float_or_complex_dtype():
-    dtypes = (str, bool, int, np.uint32,
-              np.float16, np.float32, np.float64, np.float128,
-              np.complex64, np.complex128, np.complex256,
-              '>f2', '>f4', '>f8', '>f16',
-              '>c8', '>c16', '>c32')
-    expecteds = (None, '<f8', '<f8', '<f8',
-                 '<f2', '<f4', '<f8', '<f16',
-                 '<c8', '<c16', '<c32',
-                 '>f2', '>f4', '>f8', '>f16',
-                 '>c8', '>c16', '>c32')
+    dtypes = [str, bool, int, np.uint32,
+              np.float16, np.float32, np.float64,
+              np.complex64, np.complex128,
+              '>f2', '>f4', '>f8',
+              '>c8', '>c16']
+    expecteds = [None, '<f8', '<f8', '<f8',
+                 '<f2', '<f4', '<f8',
+                 '<c8', '<c16',
+                 '>f2', '>f4', '>f8',
+                 '>c8', '>c16']
+    if hasattr(np, 'float128'):
+        dtypes.extend([np.float128, '>f16', np.complex256, '>c32'])
+        expecteds.extend(['<f16', '>f16', '<c32', '>c32'])
 
     def func(dtype, expected):
         if expected is None:
@@ -306,7 +293,7 @@ def test_inspect_special_values():
 
     def func(x):
         assert_eq(inspect_special_values(x), ref(x))
-    for d in dtypes:
+    for d in [bool] + DTYPES:
         for x in ((1, 1.1, 0, -1, -1), (-1, -1), (0, 0), (1, 1), (2, 2),
                   (2, 1), np.random.random_integers(-1, 1, size=10)):
             x = np.asarray(x).astype(d)
@@ -365,13 +352,15 @@ def test_least_greater_multiple():
 
 
 def test_one_pi_zero():
-    expected = 1, 4 * np.arctan(np.array(1, np.float128)), 0
+
+    expected = 1, 4 * np.arctan(np.array(1, BIGGEST_FLOAT_TYPE)), 0
 
     def func(f, dtype, exp):
+        actual = f(dtype)
+        assert_equal(actual.dtype, dtype)
         assert_same(f(dtype), np.array(exp, dtype=dtype))
     for f, exp in zip((one, pi, zero), expected):
-        for dtype in (np.float16, np.float32, np.float64, np.float128,
-                      np.complex64, np.complex128, np.complex256):
+        for dtype in FLOAT_DTYPES + COMPLEX_DTYPES:
             yield func, f, dtype, exp
 
 
